@@ -13,8 +13,8 @@ class GameBotServer:
 
     def __init__(self, host: str = None, port: str = None, timeout=5, config=None):
         ini = Ini(Path(config)) if config else Ini(self.PATH)
-        self.host = host or ini['NETWORK'] and ini['NETWORK']['host'] or '127.0.0.1'
-        self.port = port and int(port) or ini['NETWORK'] and int(ini['NETWORK']['port']) or 65432
+        self.host = host or ini['SERVER'] and ini['SERVER']['host'] or '0.0.0.0'
+        self.port = port and int(port) or ini['SERVER'] and int(ini['SERVER']['port']) or 65432
         self.selector = selectors.DefaultSelector()
         self.lsock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         self.lsock.settimeout(timeout)
@@ -147,7 +147,7 @@ class GameBotServer:
         self.data[header.server_id] = [data.decode()]
         self.write(header.from_address, outgoing_data)  # Should be ready to write
 
-    def wite_to_admin(self, data: Stream):
+    def write_to_admin(self, data: Stream):
         outgoing_data = {"success": f"{data.decode()}"}
         header = data.header
         if header.server_id not in self.servers:
